.. PET Processing Module documentation master file, created by
   sphinx-quickstart on Fri Mar 15 13:49:14 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

####################
PETPAL Documentation
####################

.. toctree::
   :includehidden:
   :hidden:
   :maxdepth: 1

   autoapi/index
   tutorials/index

.. grid:: 1 1 2 2
   :gutter: 2 3 4 4

   .. grid-item-card:: Installation
      :text-align: center

      +++

      .. button-ref:: index
         :expand:
         :color: secondary
         :click-parent:

         To the installation guide (stub)

   .. grid-item-card:: Tutorials
      :text-align: center

      +++

      .. button-ref:: tutorials/index
         :expand:
         :color: secondary
         :click-parent:

         To PETPAL tutorials


   .. grid-item-card:: API Reference
      :text-align: center

      +++

      .. button-ref:: autoapi/index
         :expand:
         :color: secondary
         :click-parent:

         To the API reference guide



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
